@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jimmy Do <crispyleaves@gmail.com>
+ * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,13 +16,18 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
  
-#ifndef MANAGE_PROFILES_WINDOW_H
-#define MANAGE_PROFILES_WINDOW_H
+#ifndef MANAGE_PRESETS_WINDOW_H
+#define MANAGE_PRESETS_WINDOW_H
 #include <gtk/gtk.h>
+#include "gloo/gloo-presets.h"
+
+G_BEGIN_DECLS
 
 GtkWidget *
-manage_presets_window_new (void);
+manage_presets_window_new (GlooPresets *gloo_presets);
 void
 manage_presets_window_open (GtkDialog *manage_presets_window);
 
-#endif /* MANAGE_PROFILES_WINDOW_H */
+G_END_DECLS
+
+#endif /* MANAGE_PRESETS_WINDOW_H */
