@@ -226,8 +226,7 @@ construct_current_time_str (void)
 	
 	{
 		size_t num_chars;
-		/* "hh:mm AM/PM" format string for strftime */
-		num_chars = strftime (time_str, sizeof (time_str), _("%I:%M %p"), time_info);
+		num_chars = strftime (time_str, sizeof (time_str), "%X", time_info);
 		g_assert (num_chars > 0);
 	}
 
@@ -461,8 +460,6 @@ set_ui_to_finished_state (TimerApplet *timer_applet)
 	g_free (timer_done_str);
 	timer_done_str = NULL;
 
-	play_notify_sound (timer_applet);
-
 	if (timer_applet->main_remaining_time_label) {
 		gtk_label_set_text (GTK_LABEL (timer_applet->main_remaining_time_label),
 							_("Finished"));
@@ -595,7 +592,7 @@ construct_applet_content (TimerApplet *timer_applet)
 static void
 update_main_button (TimerApplet *timer_applet)
 {
-	TRACE_MSG ("update_main_button\n");
+	TRACE_MSG ("update_main_button");
 
 	g_assert (timer_applet);
 	g_assert (timer_applet->main_button);
@@ -814,6 +811,19 @@ ask_user_continue_timer (TimerApplet *timer_applet)
 	}
 }
 
+static void
+set_default_window_icon (void)
+{
+	gboolean icon_set;
+	GError *err;
+
+	icon_set = gtk_window_set_default_icon_from_file (PIXMAPS_DIR "/timer-applet-icon.png",
+													  &err);
+	if (!icon_set) {
+		g_print("Couldn't set default window icon: %s\n", err->message);
+	}
+}
+
 static void
 libnotify_notify_finished (TimerApplet *timer_applet)
 {
@@ -855,7 +865,7 @@ libnotify_notify_finished (TimerApplet *timer_applet)
 		g_assert (!timer_applet->notify);
 		timer_applet->notify = notify_notification_new (_("Timer Finished") /* summary */,
 														timer_done_str /* message */,
-														NULL /* icon */,
+														GTK_STOCK_DIALOG_INFO /* icon */,
 														GTK_WIDGET (timer_applet->applet));
 		g_free (timer_done_str);
 		timer_done_str = NULL;
@@ -906,9 +916,9 @@ timer_applet_init (TimerApplet *timer_applet, PanelApplet *panel_applet)
 	if (global_gloo_presets == NULL) {
 		/* Perform one-time initialization */
 		global_gloo_presets = g_object_new (GLOO_TYPE_PRESETS, NULL);
-						
-		gnome_window_icon_set_default_from_file (PIXMAPS_DIR "/timer-applet-icon.png");
-
+		
+		set_default_window_icon ();
+		
 		g_assert (manage_presets_window == NULL);
 		manage_presets_window = manage_presets_window_new (global_gloo_presets);
 		g_assert (manage_presets_window);
@@ -1217,6 +1227,7 @@ on_gloo_timer_state_changed (GlooTimer *timer, gpointer user_data)
 	g_print ("GlooTimer state changed to: %d\n", gloo_timer_get_state (timer));
 
 	if (gloo_timer_get_state (timer) == GLOO_TIMER_STATE_FINISHED) {
+		play_notify_sound (timer_applet);
 		libnotify_notify_finished (timer_applet);
 	}
 #if HAVE_LIBNOTIFY
